<?php

declare(strict_types=1);

/*
 * This file is part of Laravel Exceptions.
 *
 * (c) Graham Campbell <graham@alt-three.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace GrahamCampbell\Exceptions\Filter;

use Illuminate\Http\Request;
use Throwable;

/**
 * This is the content type filter class.
 *
 * @author Graham Campbell <graham@alt-three.com>
 */
final class ContentTypeFilter implements FilterInterface
{
    /**
     * Filter and return the displayers.
     *
     * @param \GrahamCampbell\Exceptions\Displayer\DisplayerInterface[] $displayers
     * @param \Illuminate\Http\Request                                  $request
     * @param \Throwable                                                $original
     * @param \Throwable                                                $transformed
     * @param int                                                       $code
     *
     * @return \GrahamCampbell\Exceptions\Displayer\DisplayerInterface[]
     */
    public function filter(array $displayers, Request $request, Throwable $original, Throwable $transformed, int $code)
    {
        foreach ($displayers as $index => $displayer) {
            if (!$request->accepts($displayer->contentType())) {
                unset($displayers[$index]);
            }
        }

        return array_values($displayers);
    }
}
